@@ -90,7 +90,18 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         o = random.choice(os)
         f = random.choice(firevers)
         return "Mozilla/5.0 ({0}; Win64; x64; rv:{1}) Gecko/20100101 Firefox/{1}".format(o,f)
-    #print("# {}".format(title),file=sys.stderr,flush=True)
+    def cid(c) :
+        if type(c) in [list,tuple] :
+            s = c[0]
+        else :
+            s = c
+        if not s :
+            return 0
+        m = re.search(r"(\d+)\.htm",s)
+        if m :
+            return int(m.group(1))
+        else :
+            return 0
     ss = requests.Session()
     tgtdir = os.path.expanduser(tgtdir)
     if not os.path.isdir(tgtdir) :
@@ -114,9 +125,9 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         with open(os.path.join(tgtdir,title, "downloaded.txt"),"r",encoding="UTF-8") as f :
             downloaded = set([ln.rstrip() for ln in f.readlines()])
             if force and len(downloaded) > 1 :
-                last = sorted(list(downloaded))[-(force+1)]
+                last = sorted(list(downloaded),key=cid)[-(force+1)]
             elif downloaded :
-                last = max(downloaded)
+                last = max(downloaded,key=cid)
             else :
                 pass
     try :
@@ -134,8 +145,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
     else :
         rsp.encoding = rsp.apparent_encoding
     rtext = rsp.text
-    if debug :
-        print(rtext)
+    #if debug :
+    #    print(rtext)
     chapters = list()
     for m in re.findall(r"(<td|<dd|<li|<span)[^<>]*?>\s*<a\s+href\s*=\s*\"(\S*?\d+\.(htm|html))\".*?>\s*(.*?)\s*</a>",rtext,re.DOTALL) :
         if debug :
@@ -151,25 +162,16 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         chapter = re.sub(r"（.*）","",chapter)
         chapter = re.sub(r"\(.*\)","",chapter)
         chapters.append((url,chapter))
-    def cid(c) :
-        s = c[0]
-        if not s :
-            return 2**60
-        s = re.sub(r"(\.html|\.htm)",'',s)
-        m = re.search(r"(\d+)",s)
-        if m :
-            return 2**(30+len(m.group(1)))+int(m.group(1))
-        else :
-            return 2**60
     maxc = "n/a"
     chapters = sorted(list(set(chapters)),key=cid)
     if chapters :
         maxc = chapters[-1][0]
+    if debug :
+        print(chapters)
+        print("max chapter = ",maxc)
     if maxc == last :
         print("# No update.",file=sys.stderr,flush=True)
         return "# No update : {}".format(title)
-    if debug :
-        print(chapters)
     report=""
     cdone=0
     for ix, m in enumerate(chapters) :
@@ -178,7 +180,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         url=m[0]
         cname = url
         # redownload the last chapter to fix the prev/next link
-        if cname and cname < last :
+        if cname and cid((cname,)) < cid((last,)) :
             continue
         if page.endswith(".htm") or page.endswith(".html") :
             if root :
@@ -203,8 +205,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         except :
            print("# {}".format(traceback.format_exc().splitlines()[-1]),file=sys.stderr,flush=True)
            break
-        if debug :
-            print(rsp.text)
+        #if debug :
+        #    print(rsp.text)
         m = re.search(r"<div (class|id)=\"content\".*?>(.*?)</div>",rsp.text,re.DOTALL)
         context = ""
         divgood = True
@@ -230,7 +232,7 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
                     context += ln
         if len(context) < 200 :
             print("# context length abnormal. chapter skipped.", file=sys.stderr, flush=True)
-            continue
+            context = "PLACEHOLDER"
         context = re.sub(r"</br>","<br/>",context)
         context = re.sub(r"<br\s+/>","<br/>",context)
         context = context.replace("<br/>","<br/><br/>")
@@ -240,6 +242,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         context = context.replace("&nbsp;","")
         context = re.sub(r"\<div\>.*?\<\/div\>","",context,flags=re.DOTALL)
         context = re.sub(r"\<span\>.*?\<\/span\>","",context,flags=re.DOTALL)
+        context = context.replace("<div","\n<div")
+        context = context.replace("<span","\n<span")
         if exlist :
             newtxt = ""
             for ln in context.splitlines() :
